<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Changelog Dialog</title>
  <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&display=swap" rel="stylesheet">
  <style>
    body {
      font-family: 'Poppins', sans-serif;
      background-color: #121212;
      color: #ffffff;
      display: flex;
      justify-content: center;
      align-items: center;
      height: 100vh;
      margin: 0;
      overflow: hidden;
    }

    .dialog-overlay {
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 100%;
      background-color: rgba(0, 0, 0, 0.7);
      display: flex;
      justify-content: center;
      align-items: center;
      visibility: hidden;
      opacity: 0;
      transition: visibility 0.3s, opacity 0.5s;
    }

    .dialog {
      background-color: #1e1e1e;
      padding: 30px;
      border-radius: 15px;
      width: 500px;
      max-height: 70vh;
      overflow-y: auto;
      box-shadow: 0 10px 30px rgba(0, 0, 0, 0.7);
      text-align: center;
      position: relative;
      transform: scale(0.7);
      transition: transform 0.3s ease;
    }

    .dialog.visible {
      transform: scale(1);
    }

    .dialog-title {
      font-size: 26px;
      font-weight: 600;
      color: #ffffff;
      margin-bottom: 12px;
    }

    .dialog-subtitle {
      font-size: 18px;
      color: #b0b0b0;
      margin-bottom: 25px;
    }

    .changelog-list {
      list-style-type: none;
      padding: 0;
      margin: 0;
    }

    .changelog-list li {
      background-color: #2c2c2c;
      margin-bottom: 12px;
      padding: 15px;
      border-radius: 10px;
      display: flex;
      align-items: center;
      transition: background-color 0.3s;
    }

    .changelog-list li:hover {
      background-color: #3a3a3a;
    }

    .changelog-list li .changelog-icon {
      width: 40px;
      height: 40px;
      border-radius: 50%;
      background-color: #6363ff;
      display: inline-block;
      margin-right: 15px;
      position: relative;
    }

    .changelog-list li .changelog-icon::after {
      content: '🔄';
      font-size: 24px;
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
    }

    .close-btn {
      position: absolute;
      top: 15px;
      right: 15px;
      width: 25px;
      height: 25px;
      cursor: pointer;
      color: #ffffff;
      border: none;
      background-color: transparent;
      font-size: 24px;
      line-height: 24px;
      transition: color 0.3s;
    }

    .close-btn:hover {
      color: #6363ff;
    }

    .dialog-overlay.visible {
      visibility: visible;
      opacity: 1;
    }

    /* Custom Scrollbar Styling */
    .dialog::-webkit-scrollbar {
      width: 8px;
    }

    .dialog::-webkit-scrollbar-track {
      background: #1e1e1e;
      border-radius: 10px;
    }

    .dialog::-webkit-scrollbar-thumb {
      background: #6363ff;
      border-radius: 10px;
      transition: background-color 0.3s;
    }

    .dialog::-webkit-scrollbar-thumb:hover {
      background: #4b4bff;
    }
  </style>
</head>
<body>

  <div class="dialog-overlay" id="dialogOverlay" onclick="outsideClick(event)">
    <div class="dialog" id="dialog">
      <button class="close-btn" onclick="closeDialog()">×</button>
      <div class="dialog-title">Changelog</div>
      <div class="dialog-subtitle">Recent updates for this page</div>
      <ul class="changelog-list" id="changelogList">
        <li>
          <div class="changelog-icon"></div>
          <div>
            <span class="changelog-title">New Feature!</span>
            <p class="changelog-desc">Added the ability to filter results.</p>
          </div>
        </li>
        <li>
          <div class="changelog-icon"></div>
          <div>
            <span class="changelog-title">Bug Fix</span>
            <p class="changelog-desc">Resolved an issue with data loading.</p>
          </div>
        </li>
        <li>
          <div class="changelog-icon"></div>
          <div>
            <span class="changelog-title">UI Update</span>
            <p class="changelog-desc">Improved layout for better usability.</p>
          </div>
        </li>
      </ul>
    </div>
  </div>

  <script>
    function openDialog() {
      const dialogOverlay = document.getElementById('dialogOverlay');
      const dialog = document.getElementById('dialog');
      dialogOverlay.classList.add('visible');
      setTimeout(() => {
        dialog.classList.add('visible');
      }, 100);
    }

    function closeDialog() {
      const dialogOverlay = document.getElementById('dialogOverlay');
      const dialog = document.getElementById('dialog');
      dialog.classList.remove('visible');
      setTimeout(() => {
        dialogOverlay.classList.remove('visible');
      }, 300);
    }

    function outsideClick(event) {
      const dialog = document.getElementById('dialog');
      if (event.target === dialog.parentNode) {
        closeDialog();
      }
    }

    function checkForChangeParam() {
      const urlParams = new URLSearchParams(window.location.search);
      if (urlParams.has('change')) {
        openDialog();
      }
    }

    // Check for the change parameter when the page loads
    window.onload = checkForChangeParam;
  </script>

</body>
</html>
