<?php
session_start();
require_once '../database/database_connection.php'; // Include database connection

// Check if the user is logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header('Location: login.php');
    exit;
}

$uniqueid = isset($_GET["uniqueid"]) ? urldecode($_GET["uniqueid"]) : "";

// Fetch the record details from the database based on the uniqueid
$sql = "SELECT * FROM love WHERE uniqueid = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $uniqueid);
$stmt->execute();
$result = $stmt->get_result();
$data = $result->fetch_assoc();

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Handle form submission and update the database
    $name = $_POST['name'] ?: null;
    $status = $_POST['status'] ?: null;
    $viewed = $_POST['viewed'] ?: null;
    $blocked = $_POST['blocked'] ?: null;
    $pincode = $_POST['pincode'] ?: null;
    $invoicenumber = $_POST['invoicenumber'] ?: null;
    $email = $_POST['email'] ?: null;
    $phone = $_POST['phone'] ?: null;
    $gender = $_POST['gender'] ?: null;
    $city = $_POST['city'] ?: null;
    $state = $_POST['state'] ?: null;
    $date = $_POST['date'] ?: null;
    $duedate = $_POST['duedate'] ?: null;
    $address = $_POST['address'] ?: null;
    $amount = $_POST['amount'] ?: null;
    $gst = $_POST['gst'] ?: null;
    $paid = isset($_POST['paid']) ? 1 : 0;
    $invoicegenerated = isset($_POST['invoicegenerated']) ? 1 : 0;

    // Update the record
    $update_sql = "UPDATE love SET
        name = ?, status = ?, viewed = ?, blocked = ?, ip = ?, pincode = ?, invoicenumber = ?, email = ?, phone = ?, gender = ?, 
        city = ?, state = ?, date = ?, duedate = ?, address = ?, amount = ?, gst = ?, paid = ?, invoicegenerated = ?
        WHERE uniqueid = ?";
    
    $stmt_update = $conn->prepare($update_sql);
    $stmt_update->bind_param("ssssssssssssssssssss", $name, $status, $viewed, $blocked, $_SERVER['REMOTE_ADDR'], 
                            $pincode, $invoicenumber, $email, $phone, $gender, $city, $state, $date, $duedate, $address, 
                            $amount, $gst, $paid, $invoicegenerated, $uniqueid);
    
    if ($stmt_update->execute()) {
        // Redirect after successful submission to prevent form resubmission
        header("Location: user.php?uniqueid=" . urlencode($uniqueid));
        exit;
    } else {
        echo "<div class='alert alert-danger'>Error updating record: " . $conn->error . "</div>";
    }
}
?>


<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit User Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr@4.6.9/dist/flatpickr.min.css">
</head>
<body>
    <div class="container mt-5">
        <h1>GENRATE INVOICE</h1>
        <form action="user.php?uniqueid=<?php echo urlencode($uniqueid); ?>" method="POST">
            <div class="row">
                <div class="col-md-6 mb-3">
                    <label for="name" class="form-label">Name</label>
                    <input type="text" class="form-control" name="name" id="name" value="<?php echo $data['name']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="status" class="form-label">Status</label>
                    <input type="text" class="form-control" name="status" id="status" value="<?php echo $data['status']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="viewed" class="form-label">Viewed</label>
                    <input type="text" class="form-control" name="viewed" id="viewed" value="<?php echo $data['viewed']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="blocked" class="form-label">Blocked</label>
                    <input type="text" class="form-control" name="blocked" id="blocked" value="<?php echo $data['blocked']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="pincode" class="form-label">Pincode</label>
                    <input type="text" class="form-control" name="pincode" id="pincode" value="<?php echo $data['pincode']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="invoicenumber" class="form-label">invoice number</label>
                    <input type="text" class="form-control" name="invoicenumber" id="invoicenumber" value="<?php echo $data['invoicenumber']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="email" class="form-label">Email</label>
                    <input type="email" class="form-control" name="email" id="email" value="<?php echo $data['email']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="phone" class="form-label">Phone</label>
                    <input type="text" class="form-control" name="phone" id="phone" value="<?php echo $data['phone']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="gender" class="form-label">Gender</label>
                    <input type="text" class="form-control" name="gender" id="gender" value="<?php echo $data['gender']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="city" class="form-label">City</label>
                    <input type="text" class="form-control" name="city" id="city" value="<?php echo $data['city']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="state" class="form-label">State</label>
                    <input type="text" class="form-control" name="state" id="state" value="<?php echo $data['state']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="date" class="form-label">Date</label>
                    <input type="text" class="form-control" name="date" id="date" value="<?php echo $data['date']; ?>" placeholder="YYYY-MM-DD">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="duedate" class="form-label">Due Date</label>
                    <input type="text" class="form-control" name="duedate" id="duedate" value="<?php echo $data['duedate']; ?>" placeholder="YYYY-MM-DD">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="gst" class="form-label">GST</label>
                    <input type="text"  class="form-control" name="gst" id="gst" value="<?php echo $data['gst']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="paid" class="form-label">Paid</label>
                    <input type="checkbox" name="paid" id="paid" <?php echo $data['paid'] == 1 ? 'checked' : ''; ?>>
                    <label for="paid"><?php echo $data['paid'] == 1 ? 'True' : 'False'; ?></label>
                </div>

                <div class="col-md-12 mb-3">
                    <label for="address" class="form-label">Address</label>
                    <textarea class="form-control" name="address" id="address"><?php echo $data['address']; ?></textarea>
                </div>

                <div class="col-md-6 mb-3">
                    <label for="amount" class="form-label">Amount</label>
                    <input type="text" class="form-control" name="amount" id="amount" value="<?php echo $data['amount']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="invoicegenerated" class="form-label">Invoice Generated</label>
                    <input type="checkbox" name="invoicegenerated" id="invoicegenerated" <?php echo $data['invoicegenerated'] == 1 ? 'checked' : ''; ?>>
                    <label for="invoicegenerated"><?php echo $data['invoicegenerated'] == 1 ? 'True' : 'False'; ?></label>
                </div>
            </div>

            <button type="submit" class="btn btn-primary">Save Changes</button>
        </form>
    </div>

    <!-- Bootstrap JS and Flatpickr JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/flatpickr@4.6.9/dist/flatpickr.min.js"></script>

    <script>
        // Initialize the datepicker
        flatpickr("#date", { dateFormat: "Y-m-d" });
        flatpickr("#duedate", { dateFormat: "Y-m-d" });
    </script>
</body>
</html>
