<?php
session_start();
require_once '../database/database_connection.php'; // Include database connection

// Check if the user is logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header('Location: login.php');
    exit;
}

$uniqueid = isset($_GET["uniqueid"]) ? urldecode($_GET["uniqueid"]) : "";

// Fetch the record details from the database based on the uniqueid
$sql = "SELECT * FROM love WHERE uniqueid = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("s", $uniqueid);
$stmt->execute();
$result = $stmt->get_result();
$data = $result->fetch_assoc();

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Handle form submission and update the database
    $name = $_POST['name'] ?: null;
    $user_address = $_POST['user_address'] ?: null;
    $email = $_POST['email'] ?: null;
    $pincode = $_POST['pincode'] ?: null;
    $subject = $_POST['subject'] ?: null;
    $Dealership = $_POST['Dealership'] ?: null;
    $phone = $_POST['phone'] ?: null;
    $amount = $_POST['amount'] ?: null;
    $duedate = $_POST['duedate'] ?: null;
    $dateapprovalgen = $_POST['dateapprovalgen'] ?: null;
    $address = $_POST['address'] ?: null;
    $ac_no = $_POST['ac_no'] ?: null;
    $ifsc_code = $_POST['ifsc_code'] ?: null;
    $account_holder_name = $_POST['account_holder_name'] ?: null;
    $bank = $_POST['bank'] ?: null;
    $branch = $_POST['branch'] ?: null;

    // Handle the approvalgenerated checkbox
    $approvalgenerated = isset($_POST['approvalgenerated']) ? 1 : 0;

    // Handle file upload for user_photo
    $user_photo = null;
    if (isset($_FILES['user_photo']) && $_FILES['user_photo']['error'] == 0) {
        $uploads_dir = '../users/images';  // Define the directory to upload the images
        $tmp_name = $_FILES['user_photo']['tmp_name'];
        $user_photo = $uploads_dir . '/' . basename($_FILES['user_photo']['name']);
        
        // Move the uploaded file to the desired directory
        if (move_uploaded_file($tmp_name, $user_photo)) {
            echo "File uploaded successfully.";
        } else {
            echo "File upload failed.";
        }
    }

    // Update the record
    $update_sql = "UPDATE love SET
        name = ?, user_address = ?, email = ?, pincode = ?, subject = ?, Dealership = ?, phone = ?, amount = ?, duedate = ?, 
        dateapprovalgen = ?, address = ?, ac_no = ?, ifsc_code = ?, account_holder_name = ?, bank = ?, branch = ?, user_photo = ?, approvalgenerated = ?
        WHERE uniqueid = ?";
    
    // If user_photo is null, do not include it in the update
    if ($user_photo === null) {
        $update_sql = "UPDATE love SET
            name = ?, user_address = ?, email = ?, pincode = ?, subject = ?, Dealership = ?, phone = ?, amount = ?, duedate = ?, 
            dateapprovalgen = ?, address = ?, ac_no = ?, ifsc_code = ?, account_holder_name = ?, bank = ?, branch = ?, approvalgenerated = ?
            WHERE uniqueid = ?";
    }

    $stmt_update = $conn->prepare($update_sql);
    if ($user_photo !== null) {
        $stmt_update->bind_param("sssssssssssssssssis", 
            $name, $user_address, $email, $pincode, $subject, $Dealership, $phone, $amount, $duedate, 
            $dateapprovalgen, $address, $ac_no, $ifsc_code, $account_holder_name, $bank, $branch, $user_photo, $approvalgenerated, $uniqueid);
    } else {
        $stmt_update->bind_param("ssssssssssssssssis", 
            $name, $user_address, $email, $pincode, $subject, $Dealership, $phone, $amount, $duedate, 
            $dateapprovalgen, $address, $ac_no, $ifsc_code, $account_holder_name, $bank, $branch, $approvalgenerated, $uniqueid);
    }

    if ($stmt_update->execute()) {
        // Redirect after successful submission to prevent form resubmission
        header("Location: userr.php?uniqueid=" . urlencode($uniqueid));
        exit;
    } else {
        echo "<div class='alert alert-danger'>Error updating record: " . $conn->error . "</div>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit User Details</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <h1>Edit User Details</h1>
        
        <form action="userr.php?uniqueid=<?php echo urlencode($uniqueid); ?>" method="POST" enctype="multipart/form-data">
            <div class="row">
                <!-- Display the uniqueid (Non-editable) -->
                <div class="col-md-6 mb-3">
                    <label for="uniqueid" class="form-label">Unique ID</label>
                    <input type="text" class="form-control" name="uniqueid" id="uniqueid" value="<?php echo $data['uniqueid']; ?>" readonly>
                </div>

                <!-- Other form fields (as before) -->
                <div class="col-md-6 mb-3">
                    <label for="name" class="form-label">Name</label>
                    <input type="text" class="form-control" name="name" id="name" value="<?php echo $data['name']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="user_address" class="form-label">User Address</label>
                    <input type="text" class="form-control" name="user_address" id="user_address" value="<?php echo $data['user_address']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="email" class="form-label">Email</label>
                    <input type="email" class="form-control" name="email" id="email" value="<?php echo $data['email']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="pincode" class="form-label">Pincode</label>
                    <input type="text" class="form-control" name="pincode" id="pincode" value="<?php echo $data['pincode']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="subject" class="form-label">Subject</label>
                    <input type="text" class="form-control" name="subject" id="subject" value="<?php echo $data['subject']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="Dealership" class="form-label">Dealership</label>
                    <input type="text" class="form-control" name="Dealership" id="Dealership" value="<?php echo $data['Dealership']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="phone" class="form-label">Phone</label>
                    <input type="text" class="form-control" name="phone" id="phone" value="<?php echo $data['phone']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="amount" class="form-label">Amount</label>
                    <input type="text" class="form-control" name="amount" id="amount" value="<?php echo $data['amount']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="duedate" class="form-label">Due Date</label>
                    <input type="text" class="form-control" name="duedate" id="duedate" value="<?php echo $data['duedate']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="dateapprovalgen" class="form-label">Approval Generated Date</label>
                    <input type="date" class="form-control" name="dateapprovalgen" id="dateapprovalgen" value="<?php echo $data['dateapprovalgen']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="address" class="form-label">Address</label>
                    <input type="text" class="form-control" name="address" id="address" value="<?php echo $data['address']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="ac_no" class="form-label">Account Number</label>
                    <input type="text" class="form-control" name="ac_no" id="ac_no" value="<?php echo $data['ac_no']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="ifsc_code" class="form-label">IFSC Code</label>
                    <input type="text" class="form-control" name="ifsc_code" id="ifsc_code" value="<?php echo $data['ifsc_code']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="account_holder_name" class="form-label">Account Holder Name</label>
                    <input type="text" class="form-control" name="account_holder_name" id="account_holder_name" value="<?php echo $data['account_holder_name']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="bank" class="form-label">Bank</label>
                    <input type="text" class="form-control" name="bank" id="bank" value="<?php echo $data['bank']; ?>">
                </div>

                <div class="col-md-6 mb-3">
                    <label for="branch" class="form-label">Branch</label>
                    <input type="text" class="form-control" name="branch" id="branch" value="<?php echo $data['branch']; ?>">
                </div>

                <!-- Approval Generated Checkbox -->
                <div class="col-md-6 mb-3">
                    <label for="approvalgenerated" class="form-label">Approval Generated</label>
                    <select class="form-control" name="approvalgenerated" id="approvalgenerated">
                        <option value="1" <?php echo $data['approvalgenerated'] == 1 ? 'selected' : ''; ?>>Yes</option>
                        <option value="0" <?php echo $data['approvalgenerated'] == 0 ? 'selected' : ''; ?>>No</option>
                    </select>
                </div>

                <!-- User Photo Upload -->
                <div class="col-md-6 mb-3">
                    <label for="user_photo" class="form-label">User Photo</label>
                    <input type="file" class="form-control" name="user_photo" id="user_photo">
                </div>

                <div class="col-md-12 text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </div>
        </form>
    </div>
</body>
</html>
