document.addEventListener("DOMContentLoaded", () => {
  const voiceLanguage = {
    en: "en-US",
    bn: "bn",
    bengali: "bn",
    gu: "gu",
    gujarati: "gu",
    hi: "hi",
    hindi: "hi",
    od: "or",
    oriya: "or",
    kn: "kn",
    kannada: "kn",
    ml: "ml",
    malayalam: "ml",
    mr: "mr",
    marathi: "mr",
    ta: "ta",
    tamil: "ta",
    te: "te",
    telugu: "te",
  };

  const searchInput = document.querySelector(".searchPopup .search-bar input");
  const microphoneButton = document.querySelector(".search-bar .voice-search");
  const closeButton = document.querySelector(".searchPopup .close-button");
  const currentLanguage = window.sessionStorage.getItem("CURRENT_PAGE_LANG") || "en"; 

  // Create overlay element
  const overlay = document.createElement("div");
  overlay.classList.add("overlay");
  document.body.appendChild(overlay);

  // Toggle active class on search bar click
searchInput.addEventListener("click", () => {
  const searchProd = document.querySelector(".below-container-search");
  
  // Add the active class and toggle overlay
  searchProd.classList.add("active");
  overlay.classList.toggle('overlay--active');

  // Get the position of the element relative to the top of the page
  const offsetTop = searchProd.getBoundingClientRect().top + window.scrollY;

  // Scroll to the element with an additional 100px margin
  window.scrollTo({
    top: offsetTop - 200, // Adjust for 100px margin from top
    behavior: 'smooth'
  });
});



  // Close search popup on close button click
  closeButton.addEventListener("click", () => {
    const searchProd = document.querySelector(".below-container-search");
    searchProd.classList.remove("active");
    overlay.classList.toggle('overlay--active');

   
  });

  // Close popup and overlay when clicking on the overlay
  overlay.addEventListener("click", () => {
    const searchProd = document.querySelector(".below-container-search");
    searchProd.classList.remove("active");
   overlay.classList.remove('overlay--active');
  });

  // Speech recognition setup
  function setupSearchFunctionality(inputBox, microphone, language) {
    if ("SpeechRecognition" in window || "webkitSpeechRecognition" in window) {
      const recognition = new (window.SpeechRecognition || window.webkitSpeechRecognition)();
      recognition.lang = voiceLanguage[language];
      
      microphone.addEventListener("click", function () {
        try {
          if (microphone.classList.contains("active")) {
            recognition.stop();
            microphone.classList.remove("recording");
          } else {
            recognition.start();
            microphone.classList.add("recording");
          }
        } catch (error) {
          console.error("[ERROR]: Microphone is not working properly");
        }
        microphone.classList.toggle("active");
      });

      recognition.onresult = function (event) {
        const transcript = event.results[0][0].transcript;
        inputBox.value = transcript;
        performSearch(inputBox.value, language);
      };

      recognition.onerror = function (event) {
        console.error("Speech recognition error:", event.error);
      };
    } else {
      console.error("Web Speech API is not supported in this browser.");
    }

    inputBox.addEventListener("keydown", function (event) {
      if (event.key === "Enter") {
        performSearch(inputBox.value, language);
      }
    });
  }

  // Function to handle search redirection
  function performSearch(searchTerm, language) {
    const encodedTerm = encodeURIComponent(searchTerm);
    const redirectURL =
      language === "en"
        ? `/content/ultratechcement/in/en/home/search.html?searchInput=${encodedTerm}`
        : `/content/ultratechcement/in/${language}/home/search.html?searchInput=${encodedTerm}`;
    window.location.href = redirectURL;
  }

  // Trending search redirection setup
  function setupTrendingSearchRedirection() {
    const trendingButtons = document.querySelectorAll(".search-tags button");
    trendingButtons.forEach((button) => {
      button.addEventListener("click", function () {
        const url = button.getAttribute("data-attr-link");
        if (url) {
          window.location.href = url;
        }
      });
    });
  }

  // Product item redirection based on `data-attr-link`
  function setupProductItemRedirection() {
    const productItems = document.querySelectorAll(".product-item");
    productItems.forEach((item) => {
      item.addEventListener("click", function () {
        const url = item.getAttribute("data-attr-link");
        if (url) {
          window.location.href = url;
        }
      });
    });
  }

  // Initialize functionality
  setupSearchFunctionality(searchInput, microphoneButton, currentLanguage);
  setupTrendingSearchRedirection();
  setupProductItemRedirection();
});
