<?php
// Include database connection
include('database/database_connection.php');

// Check if 'id' is set in the URL
if (isset($_GET['id']) && !empty($_GET['id'])) {
    $id = $_GET['id'];

    // Query to fetch data from 'love' table based on id
    $query = "SELECT * FROM love WHERE uniqueid = ?";
    $stmt = $conn->prepare($query);
    $stmt->bind_param("i", $id); // assuming uniqueid is an integer
    $stmt->execute();
    $result = $stmt->get_result();

    // Check if any row is returned
    if ($result->num_rows > 0) {
        $data = $result->fetch_assoc();

        // Check if invoice is generated
        if ($data['invoicegenerated'] == 1) {
            // Invoice is generated, proceed with displaying invoice details
            $name = $data['name'] ?? 'NULL';
            $email = $data['email'] ?? 'NULL';
            $phone = $data['phone'] ?? 'NULL';
            $gst = $data['gst'] ?? 'NULL';
            $amount = $data['amount'] ?? 'NULL';
            $invoiceNumber = $data['invoicenumber'] ?? 'NULL';
            $dueDate = $data['duedate'] ?? 'NULL';
            $Date = $data['date'] ?? 'NULL';
            $paid = $data['paid'] ?? 'NULL';
            $address = $data['address'] ?? 'NULL';
        } else {
            // Invoice not generated, display message
            $invoiceNotAvailable = true;
        }
    } else {
        // No data found for the given id
        $dataNotFound = true;
    }
} else {
    // id is not provided in the URL
    $idNotProvided = true;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Invoice</title>
  <link rel="preconnect" href="https://fonts.googleapis.com">
  <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
  <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap" rel="stylesheet">
  <style>
    body {
      font-family: 'Roboto', Arial, sans-serif;
      margin: 20px;
      padding: 0;
      background-color: #f4f4f4;
    }

    main {
      max-width: 900px;
      margin: 0 auto;
      background-color: white;
      padding: 20px;
      border-radius: 8px;
      box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
    }

    .header {
      display: flex;
      align-items: center;
      justify-content: space-between;
      border-bottom: 1px solid #ccc;
      padding-bottom: 10px;
      margin-bottom: 20px;
    }

    .logo {
      max-width: 150px;
    }

    .title {
      font-size: 32px;
      margin: 0;
      font-weight: bold;
      color: #333;
    }

    .section {
      border: 1px solid #ccc;
      padding: 15px;
      margin-bottom: 20px;
      border-radius: 4px;
    }

    .section h2 {
      font-weight: bold;
      margin-top: 0;
    }

    .section p {
      margin: 5px 0;
    }

    .status {
      color: green;
      font-weight: bold;
      background-color: #e8f5e9;
      padding: 5px;
      border-radius: 4px;
    }

    table {
      width: 100%;
      border-collapse: collapse;
      margin-top: 15px;
    }

    th, td {
      padding: 10px;
      text-align: left;
      font-weight: normal;
    }

    th {
      background-color: #f2f2f2;
      color: #333;
    }

    td {
      background-color: #fafafa;
    }

    .note {
      font-size: 12px;
      text-align: center;
      color: #777;
      margin-top: 30px;
    }

    .not-found {
      font-size: 48px;
      font-weight: bold;
      color: red;
      text-align: center;
      margin-top: 50px;
    }

    /* Print styles (adjustments for portrait printing) */
    @media print {
      body {
        margin: 0;
        padding: 0;
      }

      main {
        padding: 20px;
        border: 2px solid black;
      }

      th, {
        font-weight: bold;
      }
      .print-btn{
        display: none;
      }
    }

    .print-btn {
      display: inline-block;
      margin-bottom: 20px;
      padding: 10px 20px;
      background-color: #4CAF50;
      color: white;
      font-size: 16px;
      
      border: none;
      cursor: pointer;
      border-radius: 4px;
    }

    .print-btn:hover {
      background-color: #45a049;
    }
  </style>
</head>
<body>
  <main>
   

    <div class="header">
      <img src="/content/experience-fragments/ultratechcement/in/ihb/header/master1/_jcr_content/root/container_copy_86747432/container/image_copy.coreimg.png/1727338314222/ultratech-cement-logo.png" alt="UltraTech Logo" class="logo">
      <h1 class="title">Dealership</h1>
    </div>

    <?php if (isset($idNotProvided) && $idNotProvided) { ?>
        <div class="not-found">404 - Approval ID is required</div>
    <?php } elseif (isset($dataNotFound) && $dataNotFound) { ?>
        <div class="not-found">404 - No data found for the given ID</div>
    <?php } elseif (isset($invoiceNotAvailable) && $invoiceNotAvailable) { ?>
        <section class="section">
            <h2>Invoice Not Available Yet</h2>
            <p>Sorry, the invoice for this approval ID is not available yet. Please try again later.</p>
        </section>
    <?php } else { ?>
        <section class="section tax-invoice">
            <h2>TAX INVOICE</h2>
            <div class="invoice-details">
                <p><strong>Date:</strong>  <?= htmlspecialchars($Date) ?></p>
                <p><strong>Invoice Number:</strong> <?= htmlspecialchars($invoiceNumber) ?></p>
                <p><strong>Due Date:</strong> <?= htmlspecialchars($dueDate) ?></p>
                <p><strong>GST No.:</strong> <span style="color: blue;"><?= htmlspecialchars($gst) ?></span></p>
            </div>
        </section>

        <section class="section user-details">
            <h2>USER DETAILS</h2>
            <p><strong>Name:</strong> <?= htmlspecialchars($name) ?></p>
            <p><strong>Email Id:</strong> <?= htmlspecialchars($email) ?></p>
            <p><strong>Mobile No.:</strong> <?= htmlspecialchars($phone) ?></p>
        </section>

        <section class="section registration-fee">
          <h2>Registration Fee</h2>
          <p>Rs. <?= number_format($amount, 2) ?>/-</p>
          
          <?php
          if ($paid == 0) {
              echo '<p class="status" style="color: red; background-color: #f8d7da;">Not Paid</p>';
          } else {
              echo '<p class="status" style="color: green; background-color: #e8f5e9;">Paid</p>';
          }
          ?>
      </section>
      

        <section class="section summary">
            <h2>Summary</h2>
            <table>
                <tr>
                    <th>Invoice to:</th>
                    <th>Tax</th>
                    <th>Amount (INR)</th>
                </tr>
                <tr>
                    <td>Registration Fee</td>
                    <td>Including 18% GST</td>
                    <td>Rs. <?= number_format($amount, 2) ?>/-</td>
                </tr>
            </table>
        </section>

        <section class="section address">
            <p><strong>Address:</strong> <?= htmlspecialchars($address) ?></p>
        </section>

        <p class="note">No human was involved in creating this invoice, so no signature is needed.</p>
        <button class="print-btn" onclick="window.print()">Print Invoice</button>
    <?php } ?>
  </main>
   
</body>
</html> 
